# remirepo/fedora spec file for xlsxio
#
# Copyright (c) 2019-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%global gh_commit   b9399e50ee1c6122f9c35aec4755ff650349aeb5
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    brechtsanders
%global gh_project  xlsxio
%global libname     lib%{gh_project}

Name:          %{gh_project}
Summary:       XLSX tools from %{libname}
Version:       0.2.26
Release:       1%{?dist}
License:       MIT

URL:           https://github.com/%{gh_owner}/%{gh_project}/
Source0:       https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}-%{gh_short}.tar.gz

BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: cmake >= 2.6
BuildRequires: zlib-devel
# Ensure we use latest version
BuildRequires: libzip-devel >= 1.5
BuildRequires: expat-devel
BuildRequires: doxygen

Requires:      %{libname}%{?_isa} = %{version}-%{release}


%description
This package provides XLSX commands using %{libname}:
- xlsxio_csv2xlsx
- xlsxio_xlsx2csv


%package -n %{libname}
Summary:    C library for reading values from and writing values to .xlsx files
Group:      Development/Libraries

%description -n %{libname}
XLSX I/O aims to provide a C library for reading and writing .xlsx files.
The .xlsx file format is the native format used by Microsoft(R) Excel(TM)
since version 2007.


%package -n %{libname}-devel
Summary:    Header files and development libraries for %{name}
Group:      Development/Libraries
Requires:   %{libname}%{?_isa} = %{version}-%{release}

%description -n %{libname}-devel

This package contains the header files and development libraries
for %{libname}.


%prep
%setup -q -n %{gh_project}-%{gh_commit}

# Fix installation layout
sed -e '/LIBRARY DESTINATION/s/lib/%{_lib}/' \
    -e 's/DESTINATION \./DESTINATION share/' \
    -i CMakeLists.txt


%build
# TODO: WITH_WIDE requires expatw

%cmake \
  -DWITH_LIBZIP:BOOL=ON \
  -DBUILD_STATIC:BOOL=OFF \
  -DBUILD_EXAMPLES:BOOL=OFF  \
  -DWITH_WIDE:BOOL=OFF \
  .

make %{_smp_mflags}


%install
make install DESTDIR="%{buildroot}"

# Clean with old cmake version
rm -rf %{buildroot}%{_mandir}/man3/_builddir_*


%if 0%{?fedora} < 28 && 0%{?rhel} < 8
%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig
%endif


%files
%{_bindir}/%{gh_project}*


%files -n %{libname}
%{!?_licensedir:%global license %%doc}
%license LICENSE.txt
%{_libdir}/%{libname}_*.so


%files  -n %{libname}-devel
%doc *.md
%doc examples
%{_includedir}/xls*
%{_mandir}/man3/%{gh_project}*


%changelog
* Tue Mar 24 2020 Remi Collet <remi@remirepo.net> - 0.2.26-1
- update to 0.2.26
- drop patch merged upstream

* Sun Mar 22 2020 Remi Collet <remi@remirepo.net> - 0.2.25-1
- update to 0.2.25

* Thu Mar 19 2020 Remi Collet <remi@remirepo.net> - 0.2.24-2
- add patch for pec/xlswriter from
  https://github.com/viest/xlsxio

* Thu Mar 19 2020 Remi Collet <remi@remirepo.net> - 0.2.24-1
- update to 0.2.24
- drop patch merged upstream

* Tue Mar 10 2020 Remi Collet <remi@remirepo.net> - 0.2.22-1
- update to 0.2.22

* Mon Sep 16 2019 Remi Collet <remi@remirepo.net> - 0.2.21-1
- initial package
- add patch for -Werror=format-security from
  https://github.com/brechtsanders/xlsxio/pull/53
